@@ -33,8 +33,7 @@
 #include "fen-dump.h"
 
 #ifdef GIO_COMPILATION
-#define FK_W if (fk_debug_enabled) g_debug
-static gboolean fk_debug_enabled = FALSE;
+#define FK_W if (FALSE) g_debug
 #else
 #include "gam_error.h"
 #define FK_W(...) GAM_DEBUG(DEBUG_INFO, __VA_ARGS__)
@@ -302,7 +301,7 @@ psource_new()
 	return source;
 }
 
-/**
+/*
  * port_add:
  * @f:
  *
@@ -374,7 +373,7 @@ start_over:
     return errno;
 }
 
-/**
+/*
  * port_remove
  *
  * < private >
@@ -408,7 +407,7 @@ port_remove (node_t *f)
     }
 }
 
-/**
+/*
  * Get Solaris resouce values.
  *
  */
