@@ -407,11 +407,10 @@ void     g_source_add_child_source    (GSource        *source,
 void     g_source_remove_child_source (GSource        *source,
 				       GSource        *child_source);
 
-#ifndef G_DISABLE_DEPRECATED
 GLIB_DEPRECATED_FOR(g_source_get_time)
 void     g_source_get_current_time (GSource        *source,
                                     GTimeVal       *timeval);
-#endif
+
 gint64   g_source_get_time         (GSource        *source);
 
  /* void g_source_connect_closure (GSource        *source,
@@ -431,106 +430,6 @@ void   g_get_current_time                 (GTimeVal       *result);
 gint64 g_get_monotonic_time               (void);
 gint64 g_get_real_time                    (void);
 
-/* ============== Compat main loop stuff ================== */
-
-#ifndef G_DISABLE_DEPRECATED
-
-/**
- * g_main_new:
- * @is_running: set to %TRUE to indicate that the loop is running. This
- *     is not very important since calling g_main_run() will set this
- *     to %TRUE anyway.
- *
- * Creates a new #GMainLoop for th default main context.
- *
- * Returns: a new #GMainLoop
- *
- * Deprecated: 2.2: Use g_main_loop_new() instead
- */
-#define         g_main_new(is_running)  g_main_loop_new (NULL, is_running)
-
-/**
- * g_main_run:
- * @loop: a #GMainLoop
- *
- * Runs a main loop until it stops running.
- *
- * Deprecated: 2.2: Use g_main_loop_run() instead
- */
-#define         g_main_run(loop)        g_main_loop_run(loop)
-
-/**
- * g_main_quit:
- * @loop: a #GMainLoop
- *
- * Stops the #GMainLoop.
- * If g_main_run() was called to run the #GMainLoop, it will now return.
- *
- * Deprecated: 2.2: Use g_main_loop_quit() instead
- */
-#define g_main_quit(loop)       g_main_loop_quit(loop)
-
-/**
- * g_main_destroy:
- * @loop: a #GMainLoop
- *
- * Frees the memory allocated for the #GMainLoop.
- *
- * Deprecated: 2.2: Use g_main_loop_unref() instead
- */
-#define g_main_destroy(loop)    g_main_loop_unref(loop)
-
-/**
- * g_main_is_running:
- * @loop: a #GMainLoop
- *
- * Checks if the main loop is running.
- *
- * Returns: %TRUE if the main loop is running
- *
- * Deprecated: 2.2: Use g_main_loop_is_running() instead
- */
-#define g_main_is_running(loop) g_main_loop_is_running(loop)
-
-/**
- * g_main_iteration:
- * @may_block: set to %TRUE if it should block (i.e. wait) until an event
- *     source becomes ready. It will return after an event source has been
- *     processed. If set to %FALSE it will return immediately if no event
- *     source is ready to be processed.
- *
- * Runs a single iteration for the default #GMainContext.
- *
- * Returns: %TRUE if more events are pending.
- *
- * Deprecated: 2.2: Use g_main_context_iteration() instead.
- */
-#define g_main_iteration(may_block) g_main_context_iteration (NULL, may_block)
-
-/**
- * g_main_pending:
- *
- * Checks if any events are pending for the default #GMainContext
- * (i.e. ready to be processed).
- *
- * Returns: %TRUE if any events are pending.
- *
- * Deprected: 2.2: Use g_main_context_pending() instead.
- */
-#define g_main_pending()            g_main_context_pending (NULL)
-
-/**
- * g_main_set_poll_func:
- * @func: the function to call to poll all file descriptors
- *
- * Sets the function to use for the handle polling of file descriptors
- * for the default main context.
- *
- * Deprecated: 2.2: Use g_main_context_set_poll_func() again
- */
-#define g_main_set_poll_func(func)  g_main_context_set_poll_func (NULL, func)
-
-#endif /* G_DISABLE_DEPRECATED */
 
 /* Source manipulation by ID */
 gboolean g_source_remove                     (guint          tag);
