@@ -963,13 +963,8 @@ g_thread_lookup_native_funcs (void)
 G_GNUC_INTERNAL void
 g_thread_win32_init (void)
 {
-  if (g_thread_lookup_native_funcs ())
-    fprintf (stderr, "(debug) GThread using native mode\n");
-  else
-    {
-      fprintf (stderr, "(debug) GThread using Windows XP mode\n");
-      g_thread_xp_init ();
-    }
+  if (!g_thread_lookup_native_funcs ())
+    g_thread_xp_init ();
 
   InitializeCriticalSection (&g_private_lock);
 }
